All pastes #801295 Raw Edit

Something

public text v1 · immutable
#801295 ·published 2007-11-29 04:08 UTC
rendered paste body
nvidia-installer log file '/var/log/nvidia-installer.log'
creation time: Wed Nov 28 23:03:21 2007

option status:
  license pre-accepted    : false
  update                  : false
  force update            : false
  expert                  : false
  uninstall               : false
  driver info             : false
  precompiled interfaces  : true
  no ncurses color        : false
  query latest version    : false
  OpenGL header files     : true
  no questions            : false
  silent                  : false
  no recursion            : false
  no backup               : false
  kernel module only      : false
  sanity                  : false
  add this kernel         : false
  no runlevel check       : false
  no network              : false
  no ABI note             : false
  no RPMs                 : false
  no kernel module        : false
  force SELinux           : default
  no X server check       : false
  force tls               : (not specified)
  X install prefix        : (not specified)
  X library install path  : (not specified)
  X module install path   : (not specified)
  OpenGL install prefix   : (not specified)
  OpenGL install libdir   : (not specified)
  utility install prefix  : (not specified)
  utility install libdir  : (not specified)
  doc install prefix      : (not specified)
  kernel name             : (not specified)
  kernel include path     : (not specified)
  kernel source path      : (not specified)
  kernel output path      : (not specified)
  kernel install path     : (not specified)
  proc mount point        : /proc
  ui                      : (not specified)
  tmpdir                  : /tmp
  ftp mirror              : ftp://download.nvidia.com
  RPM file list           : (not specified)

Using: nvidia-installer ncurses user interface
-> License accepted.
-> There appears to already be a driver installed on your system (version: 100.
   14.19).  As part of installing this driver (version: 100.14.19), the existin
   g driver will be uninstalled.  Are you sure you want to continue? ('no' will
   abort installation) (Answer: Yes)
-> No precompiled kernel interface was found to match your kernel; would you li
   ke the installer to attempt to download a kernel interface for your kernel f
   rom the NVIDIA ftp site (ftp://download.nvidia.com)? (Answer: Yes)
-> No matching precompiled kernel interface was found on the NVIDIA ftp site;
   this means that the installer will need to compile a kernel interface for
   your kernel.
-> Performing CC sanity check with CC="cc".
-> Performing CC version check with CC="cc".
-> Kernel source path: '/lib/modules/2.6.22-14-generic/build'
-> Kernel output path: '/lib/modules/2.6.22-14-generic/build'
-> Performing rivafb check.
-> Performing nvidiafb check.
-> Performing Xen check.
-> Cleaning kernel module build directory.
   executing: 'cd ./usr/src/nv; make clean'...
   rm -f -f nv.o nv-vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nvacpi.
   o nv.o nv-vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nvacpi.o nvidi
   a.mod.o
   rm -f -f build-in.o nv-linux.o *.d .*.{cmd,flags}
   rm -f -f nvidia.{o,ko,mod.{o,c}} nv_compiler.h *~
   rm -f -f stprof stprof.o symtab.h Modules.symvers
   rm -f -rf .tmp_versions
   rm -f Makefile
-> Building kernel module:
   executing: 'cd ./usr/src/nv; make module SYSSRC=/lib/modules/2.6.22-14-gener
   ic/build SYSOUT=/lib/modules/2.6.22-14-generic/build'...
   sh ./conftest.sh "cc" "cc" /lib/modules/2.6.22-14-generic/build /lib/modules
   /2.6.22-14-generic/build cc_sanity_check full_output
   sh ./conftest.sh "cc" "cc" /lib/modules/2.6.22-14-generic/build /lib/modules
   /2.6.22-14-generic/build select_makefile full_output
   make --no-print-directory -f Makefile module
   
   NVIDIA: calling KBUILD...
   make CC=cc  KBUILD_VERBOSE=1 -C /lib/modules/2.6.22-14-generic/build SUBDIRS
   =/tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv modules
   test -e include/linux/autoconf.h -a -e include/config/auto.conf || (		\
   	echo;								\
   	echo "  ERROR: Kernel configuration is invalid.";		\
   	echo "         include/linux/autoconf.h or include/config/auto.conf are mis
   sing.";	\
   	echo "         Run 'make oldconfig && make prepare' on kernel src to fix it
   .";	\
   	echo;								\
   	/bin/false)
   mkdir -p /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/.tmp_ver
   sions
   rm -f /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/.tmp_versio
   ns/*
   make -f scripts/Makefile.build obj=/tmp/selfgz5248/NVIDIA-Linux-x86-100.14.1
   9-pkg1/usr/src/nv
   echo \#define NV_COMPILER \"`cc -v 2>&1 | tail -n 1`\" > /tmp/selfgz5248/NVI
   DIA-Linux-x86-100.14.19-pkg1/usr/src/nv/nv_compiler.h
     cc -Wp,-MD,/tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/.nv.
   o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D__KERNEL
   __ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-proto
   types -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -msoft-float
   -mregparm=3 -freg-struct-return -mpreferred-stack-boundary=2  -march=i586 -m
   tune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude/asm-i386/
   mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdeclaration-aft
   er-statement -Wno-pointer-sign -I/tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-
   pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-subs
   cripts -Wparentheses -Wpointer-arith -Wno-multichar -Werror -MD   -Wsign-com
   pare -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -
   DNVRM -DNV
   _VERSION_STRING=\"100.14.19\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_R
   LIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYS
   CTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PR
   ESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_A
   CQUIRE_CONSOLE_SEM_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_KMEM_CACHE_CREA
   TE_6_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE -D"
   KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv)"  -D"KBUILD_MODNAME=KBUI
   LD_STR(nvidia)" -c -o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/.tmp_nv.o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/nv
   .c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/nv.c:14:
   include/linux/prefetch.h: En la función ‘prefetch_range’:
   include/linux/prefetch.h:62: aviso: se usó un puntero de tipo ‘void *’ 
   en la aritmética
     cc -Wp,-MD,/tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/.nv-
   vm.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D__KER
   NEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-pr
   ototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -msoft-fl
   oat -mregparm=3 -freg-struct-return -mpreferred-stack-boundary=2  -march=i58
   6 -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude/asm-i
   386/mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdeclaration
   -after-statement -Wno-pointer-sign -I/tmp/selfgz5248/NVIDIA-Linux-x86-100.14
   .19-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-
   subscripts -Wparentheses -Wpointer-arith -Wno-multichar -Werror -MD   -Wsign
   -compare -Wno-cas
   t-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNVRM -DNV_VE
   RSION_STRING=\"100.14.19\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM
   -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_
   MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESEN
   T -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_ACQUI
   RE_CONSOLE_SEM_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_KMEM_CACHE_CREATE_6
   _PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE -D"KBUI
   LD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv_vm)"  -D"KBUILD_MODNAME=KBUIL
   D_STR(nvidia)" -c -o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src
   /nv/.tmp_nv-vm.o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/
   nv-vm.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/nv-vm.c:14:
   include/linux/prefetch.h: En la función ‘prefetch_range’:
   include/linux/prefetch.h:62: aviso: se usó un puntero de tipo ‘void *’ 
   en la aritmética
     cc -Wp,-MD,/tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/.os-
   agp.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D__KE
   RNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-p
   rototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -msoft-f
   loat -mregparm=3 -freg-struct-return -mpreferred-stack-boundary=2  -march=i5
   86 -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude/asm-
   i386/mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdeclaratio
   n-after-statement -Wno-pointer-sign -I/tmp/selfgz5248/NVIDIA-Linux-x86-100.1
   4.19-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar
   -subscri
   pts -Wparentheses -Wpointer-arith -Wno-multichar -Werror -MD   -Wsign-compar
   e -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNV
   RM -DNV_VERSION_STRING=\"100.14.19\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_S
   TRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -
   DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_S
   TATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT
   -DNV_ACQUIRE_CONSOLE_SEM_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_KMEM_CACH
   E_CREATE_6_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT  -DMODU
   LE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(os_agp)"  -D"KBUILD_MO
   DNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-p
   kg1/usr/src/nv/.tmp_os-agp.o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1
   /usr/src/nv/os-agp.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/os-agp.c:24:
   include/linux/prefetch.h: En la función ‘prefetch_range’:
   include/linux/prefetch.h:62: aviso: se usó un puntero de tipo ‘void *’ 
   en la aritmética
     cc -Wp,-MD,/tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/.os-
   interface.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include 
   -D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wst
   rict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -m
   soft-float -mregparm=3 -freg-struct-return -mpreferred-stack-boundary=2  -ma
   rch=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclud
   e/asm-i386/mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdecl
   aration-after-statement -Wno-pointer-sign -I/tmp/selfgz5248/NVIDIA-Lin
   ux-x86-100.14.19-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wf
   ormat -Wchar-subscripts -Wparentheses -Wpointer-arith -Wno-multichar -Werror
   -MD   -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KER
   NEL__ -DMODULE -DNVRM -DNV_VERSION_STRING=\"100.14.19\" -UDEBUG -U_DEBUG -DN
   DEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_
   GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESEN
   T -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB
   _BREAKPOINT_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRESENT -DNV_REMAP_PFN_RANGE_PR
   ESENT -DNV_KMEM_CACHE_CREATE_6_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VM
   AP_4_PRESENT  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(os
   _interface)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz5248/NV
   IDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/.tmp_os-interface.o /tmp/selfgz5248
   /NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/os-interface.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/os-interface.c:26:
   include/linux/prefetch.h: En la función ‘prefetch_range’:
   include/linux/prefetch.h:62: aviso: se usó un puntero de tipo ‘void *’ 
   en la aritmética
     cc -Wp,-MD,/tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/.os-
   registry.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -
   D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstr
   ict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -ms
   oft-float -mregparm=3 -freg-struct-return -mpreferred-stack-boundary=2  -mar
   ch=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude
   /asm-i386/mach-default -fo
   mit-frame-pointer -g  -fno-stack-protector -Wdeclaration-after-statement -Wn
   o-pointer-sign -I/tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv 
   -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-subscripts -Wparenth
   eses -Wpointer-arith -Wno-multichar -Werror -MD   -Wsign-compare -Wno-cast-q
   ual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE -DNVRM -DNV_VERSI
   ON_STRING=\"100.14.19\" -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -D
   NV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MA
   X_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT 
   -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_ACQUIRE
   _CONSOLE_SEM_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_KMEM_CACHE_CREATE_6_P
   RESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE -D"KBUILD
   _STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(os_registry)"  -D"KBUILD_MODNAME=K
   BUILD_STR(nvidia)" -c -o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr
   /src/nv/.tmp_os-registry.o /tmp/self
   gz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/os-registry.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/os-registry.c:14:
   include/linux/prefetch.h: En la función ‘prefetch_range’:
   include/linux/prefetch.h:62: aviso: se usó un puntero de tipo ‘void *’ 
   en la aritmética
     cc -Wp,-MD,/tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/.nv-
   i2c.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D__KE
   RNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-p
   rototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -msoft-f
   loat -mregparm=3 -freg-struct-return -mpreferred-stack-boundary
   =2  -march=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args   -
   Iinclude/asm-i386/mach-default -fomit-frame-pointer -g  -fno-stack-protector
   -Wdeclaration-after-statement -Wno-pointer-sign -I/tmp/selfgz5248/NVIDIA-Lin
   ux-x86-100.14.19-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wf
   ormat -Wchar-subscripts -Wparentheses -Wpointer-arith -Wno-multichar -Werror
   -MD   -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KER
   NEL__ -DMODULE -DNVRM -DNV_VERSION_STRING=\"100.14.19\" -UDEBUG -U_DEBUG -DN
   DEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_
   GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESEN
   T -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB
   _BREAKPOINT_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRESENT -DNV_REMAP_PFN_RANGE_PR
   ESENT -DNV_KMEM_CACHE_CREATE_6_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VM
   AP_4_PRESENT  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv
   _i2c)"  -D"KBUILD_MODNAME=KBUILD_S
   TR(nvidia)" -c -o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv
   /.tmp_nv-i2c.o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/nv
   -i2c.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/nv-i2c.c:8:
   include/linux/prefetch.h: En la función ‘prefetch_range’:
   include/linux/prefetch.h:62: aviso: se usó un puntero de tipo ‘void *’ 
   en la aritmética
     cc -Wp,-MD,/tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/.nva
   cpi.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D__KE
   RNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstrict-p
   rototypes -Wno-trigraphs -fno-strict-aliasing -fno
   -common -O2 -pipe -msoft-float -mregparm=3 -freg-struct-return -mpreferred-s
   tack-boundary=2  -march=i586 -mtune=generic -ffreestanding -maccumulate-outg
   oing-args   -Iinclude/asm-i386/mach-default -fomit-frame-pointer -g  -fno-st
   ack-protector -Wdeclaration-after-statement -Wno-pointer-sign -I/tmp/selfgz5
   248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-typ
   e -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arith -Wno-mul
   tichar -Werror -MD   -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KERNE
   L_NAMES -D__KERNEL__ -DMODULE -DNVRM -DNV_VERSION_STRING=\"100.14.19\" -UDEB
   UG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PR
   ESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_M
   ESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -
   DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_ACQUIRE_CONSOLE_SEM_PRESENT -DNV_REM
   AP_PFN_RANGE_PRESENT -DNV_KMEM_CACHE_CREATE_6_PRESENT -DNV_CHANGE_PAGE_ATTR_
   PRESENT -DNV_VMAP_4_PRESENT  -DMODUL
   E -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nvacpi)"  -D"KBUILD_MOD
   NAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pk
   g1/usr/src/nv/.tmp_nvacpi.o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/
   usr/src/nv/nvacpi.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/sr
   c/nv/nvacpi.c:15:
   include/linux/prefetch.h: En la función ‘prefetch_range’:
   include/linux/prefetch.h:62: aviso: se usó un puntero de tipo ‘void *’ 
   en la aritmética
     ld -m elf_i386 -m elf_i386  -r -o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.
   19-pkg1/usr/src/nv/nvidia.o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/
   usr/src/nv/nv-kernel.o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/s
   rc/nv/nv.o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/nv-vm.
   o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/os-agp.o /tmp/s
   elfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/os-interface.o /tmp/sel
   fgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/os-registry.o /tmp/selfgz
   5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/nv-i2c.o /tmp/selfgz5248/NVI
   DIA-Linux-x86-100.14.19-pkg1/usr/src/nv/nvacpi.o
     Building modules, stage 2.
   make -f /usr/src/linux-headers-2.6.22-14-generic/scripts/Makefile.modpost
     scripts/mod/modpost -m -a -i /usr/src/linux-headers-2.6.22-14-generic/Modu
   le.symvers -I /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/Mod
   ule.symvers -o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/Mo
   dule.symvers -w
   WARNING: could not find /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/
   src/nv/.nv-kernel.o.cmd for /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/
   usr/src/nv/nv-kernel.o
     cc -Wp,-MD,/tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/.nvi
   dia.mod.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.3/include -D
   __KERNEL__ -Iinclude  -include include/linux/autoconf.h -Wall -Wundef -Wstri
   ct-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 -pipe -mso
   ft-float -mregparm=3 -freg-struct-return -mpreferred-stack-boundary=2  -marc
   h=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude/
   asm-i386/mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdeclar
   ation-after-statement -Wno-pointer-sign    -D"KBUILD_STR(s)=#s" -D"KBUILD_BA
   SENAME=KBUILD_STR(nvidia.mod)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -DMODU
   LE -c -o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/nvidia.m
   od.o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/nv/nvidia.mod.c
     ld -m elf_i386 -m elf_i386 -r -o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.1
   9-pkg1/usr/src/nv/nvidia.ko /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/
   usr/src/nv/nvidia.o /tmp/selfgz5248/NVIDIA-Linux-x86-100.14.19-pkg1/usr/src/
   nv/nvidia.mod.o
   NVIDIA: left KBUILD.
-> done.
-> Kernel module compilation complete.
-> Kernel messages:
   [   33.163016] kjournald starting.  Commit interval 5 seconds
   [   33.163248] EXT3 FS on hda4, internal journal
   [   33.163253] EXT3-fs: mounted filesystem with ordered data mode.
   [   33.897833] input: Power Button (FF) as /class/input/input5
   [   33.897863] ACPI: Power Button (FF) [PWRF]
   [   33.897927] input: Power Button (CM) as /class/input/input6
   [   33.897954] ACPI: Power Button (CM) [PWRB]
   [   33.931563] No dock devices found.
   [   35.281988] ppdev: user-space parallel port driver
   [   35.756955] audit(1196308949.587:3):  type=1503
   operation="inode_permission" requested_mask="a" denied_mask="a"
   name="/dev/tty" pid=4945 profile="/usr/sbin/cupsd"
   [   35.850523] apm: BIOS version 1.2 Flags 0x07 (Driver version 1.16ac)
   [   35.850531] apm: disabled - APM is not SMP safe.
   [   36.844461] Failure registering capabilities with primary security
   module.
   [   37.000013] Bluetooth: Core ver 2.11
   [   37.000192] NET: Registered protocol family 31
   [   37.000197] Bluetooth: HCI device and connection manager initialized
   [   37.000202] Bluetooth: HCI socket layer initialized
   [   37.009606] Bluetooth: L2CAP ver 2.8
   [   37.009613] Bluetooth: L2CAP socket layer initialized
   [   37.060074] Bluetooth: RFCOMM socket layer initialized
   [   37.060219] Bluetooth: RFCOMM TTY layer initialized
   [   37.060223] Bluetooth: RFCOMM ver 1.8
   [   39.175130] eth0: no IPv6 routers present
   [  118.792760] PCI: Setting latency timer of device 0000:01:00.0 to 64
   [  118.793455] NVRM: loading NVIDIA UNIX x86 Kernel Module  100.14.19  Wed
   Sep 12 14:12:24 PDT 2007
-> Installing both new and classic TLS OpenGL libraries.
-> Parsing log file:
-> done.
-> Validating previous installation:
-> done.
-> Uninstalling NVIDIA Accelerated Graphics Driver for Linux-x86 (1.0-1001419
   (100.14.19)):
-> done.
-> Uninstallation of existing driver: NVIDIA Accelerated Graphics Driver for
   Linux-x86 (100.14.19) is complete.
-> Searching for conflicting X files:
-> done.
-> Searching for conflicting OpenGL files:
-> done.
-> Installing 'NVIDIA Accelerated Graphics Driver for Linux-x86' (100.14.19):
   executing: '/sbin/ldconfig'...
   executing: '/sbin/depmod -aq'...
-> done.
-> Driver file installation is complete.
-> Running post-install sanity check:
-> done.
-> Post-install sanity check passed.
-> Shared memory test passed.
-> Running runtime sanity check:
-> done.
-> Runtime sanity check passed.
-> Would you like to run the nvidia-xconfig utility to automatically update you
   r X configuration file so that the NVIDIA X driver will be used when you res
   tart X?  Any pre-existing X configuration file will be backed up. (Answer: N
   o)
-> Installation of the NVIDIA Accelerated Graphics Driver for Linux-x86
   (version: 100.14.19) is now complete.  Please update your XF86Config or
   xorg.conf file as appropriate; see the file
   /usr/share/doc/NVIDIA_GLX-1.0/README.txt for details.